@@ -8,7 +8,7 @@ is only supported in HTML. Please set your email client to display this message
 in HTML, or use an email client that supports HTML emails.
 """
 
-def send_HTML_email(subject, recipient, html_content, text_content=None, cc=None, email_from=None):
+def send_HTML_email(subject, recipient, html_content, text_content=None, cc=None, email_from=None, file_attachments=None):
     if not text_content:
         text_content = getattr(settings, 'NO_HTML_EMAIL_MESSAGE',
                                NO_HTML_EMAIL_MESSAGE)
@@ -30,7 +30,9 @@ def send_HTML_email(subject, recipient, html_content, text_content=None, cc=None
 
     from_header = {'From': email_from}  # From-header
     connection = get_connection()
-    
     msg = EmailMultiAlternatives(subject, text_content, email_return_path, [recipient], headers=from_header, connection=connection, cc=cc)
+    for file in (file_attachments or []):
+        if file:
+            msg.attach(file["title"], file["file_obj"].getvalue(), file["mimetype"])
     msg.attach_alternative(html_content, "text/html")
-    msg.send()
+    msg.send()
\ No newline at end of file
